# Emerging Trajectories

Open source library for tracking and saving forecasts of political, economic, and social events.

👋 **The code in this repository is quite messy as we experiment with, and implement, our [roadmap](https://emergingtrajectories.com/c/roadmap-q1-2024).** We'll be running a cleanup, commenting, etc. sprint once we build out all the relevant features.

## Installation

```bash
pip install emergingtrajectories
```

## Questions?

Visit our site: https://emergingtrajectories.com/

Please reach out: hello --at-- phaseai --dot-- com
